Version History
===============

Version 0.7.8
-------------
* Adds missing includes in MANIFEST.in
* Support for running tests via setuptools
* Updated microsofttranslator dependency version

Version 0.7.7
-------------
* Supported Django versions are now 1.7, 1.8 and 1.9
* Added proper documentation
* Fixed typo in documentation (PR #130, thanks @dfrdmn)
* Fixes the Fuzzy toggle link by adding an actual toggle checkbox (Issue #132, thanks @EmilStenstrom)
* Better handling of Custom User Models while checking wether the current User is authorized to translate (Issue #131, thanks @EmilStenstrom)
* Include the testproject in the sdist tarball to allow Debian to run tests during installation (Issue #137, thanks @fladi)
* Display an explicit error message to the enduser when saving the POfile fails for some reason (Issue #135, thanks @pgcd)
* Added support for PEP 3101 string formatting (PR #140, thanks @adamjforster)
* Added support for composite locales, e.g. 'bs-Cyrl-BA' (Issue #142, thanks @felarov)
* Fixed a misplaced CSRF token (PR #145, thanks @pajod)


Version 0.7.6
-------------
* Added support for the Free Google Translate API (PR #117, thanks @cuchac)
* Probable fix for apps defined by their AppConfig causing havoc in Django 1.7 and later (Issues #113 and #125)
* Test configuration improved to test against Django 1.8 beta 1 and Django 1.7.5
* Require polib >= 1.0.6 (PR #127, thanks @NotSqrt)
* Test against Django 1.8 final


Version 0.7.5
-------------
* Fixed external JavaScript import to be url scheme independent (PR #101, thanks @tsouvarev)
* Fixed a test
* Added support for excluding certain locale paths from the list of PO catalogs (PR #102, thanks @elpaso)
* Added support for translator groups (PR #103, thanks @barklund)
* Removed Microsoft Translator as a shipped lib, relying on an external version instead
* Improved the app loading mechanism to cope with Django 1.7's new AppConfig (thanks @artscoop)
* Fixed a couple inconsistencies in the German translation. (thanks @benebun)
* Use content_type instead of mimetype in HttpResponse. (Issue #115, thanks @vesteinn)
* Don't assume that request.user has settable properties, this was a silly idea anyway (Issue #114, thanks @stevejalim)
* Preserve HTML code when receiving translations from the Yandex translation service (Issue #116, thanks @marcbelmont)
* Use TOX for testing
* Test against Django 1.8a


Version 0.7.4
-------------
* New ROSETTA_POFILENAMES setting. (PR #44, thanks @wrboyce)
* Updated Czech translation (#97, #99 thanks @cuchac)
* Fixed gettext standard compliance of all shipped translations
* No longer ship polib, rely on the Cheeseshop instead


Version 0.7.3
-------------
* Fix for test settings leaking onto global settings: LANGUAGES was overridden and not set back (Issue #81 - Thanks @zsoldosp)
* Test against Django 1.6.1
* Missing context variable in catalog list (Issue #87 - Thanks @kunitoki)
* Added support for Yandex translation API (Issue #89 - Thanks @BlackWizard) See supported languages and limitations here: https://github.com/mbi/django-rosetta/pull/89
* Added support for the Azure translation API, replacing the BING API. (Issue #86, thanks @davidkuchar and @maikelwever)
* Removed support for the signed_cookies SESSION_ENGINE + SessionRosettaStorage in Django 1.6, because serialization of POFiles would fail
* Simplified the group membership test (Issue #90 - Thanks @dotsbb)
* Better serving of admin static files. (Issue #61, thanks @tback)
* Dropped Django 1.3 support


Version 0.7.2
-------------
* Fix for when settings imports unicode_literals for some reason (Issue #67)
* Fixed mess with app_id between pages (Issue #68, thanks @tsouvarev)
* Added Farsi translation. Thanks, @amiraliakbari
* Improved the permission system, allowing for more advanced permission mechanisms. Thanks, @codeinthehole and @tangentlabs
* Fixed the ordering of apps in the language selection screen. (Issue #73, thanks @tsouvarev, @kanu and everyone else involved in tracking this one down)
* Support for complex locale names. (Issue #71, Thanks @strycore)
* Configurable cache name (Issue #75, Thanks @Karmak23)

Version 0.7.1
-------------
* Fix: value missing in context

Version 0.7.0
-------------
* Support for Django 1.5 and HEAD, support for Python 3.
* Upgraded bundled polib to version 1.0.3 - http://pypi.python.org/pypi/polib/1.0.3
* Support timezones on the last modified PO header. Thanks @jmoiron (Issue #43)
* Actually move to the next block when submitting a lot of translations (Issue #13)
* Add msgctxt to the entry hash to differentiate entries with context. Thanks @metalpriest (Issue #39)
* Better discovery of locale files on Django 1.4+ Thanks @tijs (Issues #63, #64)
* List apps in alphabetical order

Version 0.6.8
-------------
* Switched to a pluggable storage backend model to increase compatibility with Django 1.4. Cache and Session-based storages are provided.

Version 0.6.7
-------------
* Added a testproject to run tests
* Updated french translation. Thanks, @BertrandBordage
* Merged @sleepyjames' PR that fixes an error when pofile save path contains '.po' in the path
* Merged @rory's PR to correcty handle plural strings that have a leading/trailing newline (Issue #34)

Version 0.6.6
-------------
* Django 1.4 support (Issue #30, #33)
* Better handling of translation callbacks on Bing's translation API and support of composite locales (Issue #26)

Version 0.6.5
-------------
* Updated polib to 0.7.0
* Added ROSETTA_POFILE_WRAP_WIDTH setting to track the line-length of the updated Po file. (Issue #24)
* Renamed the ``messages``context variable to ``rosetta_messages`` prevent conflicts with ``django.contrib.messages`` (Issue #23)

Version 0.6.4
-------------
* Added ROSETTA_REQUIRES_AUTH option to grant access to non authenticated users (False by default)

Version 0.6.3
-------------
* Support for the Bing transation API service to replace Google's service which is no longer free.
